@@ -4,8 +4,8 @@ from models import InboxMessage, OutboxMessage
 class InboxAdmin(admin.ModelAdmin):
     list_display = [
           'date_received'
-        , 'phone_number'
-        , 'action'
+        , 'from'
+        , 'message'
     ]
 
 class OutboxAdmin(admin.ModelAdmin):
@@ -13,13 +13,9 @@ class OutboxAdmin(admin.ModelAdmin):
          'date_sent'
         , 'to'
         , 'message'
-        , 'status'
+        , 'send_status'
+        , 'send_error'
     ]
 
-    def status(self, msg):
-        if not msg.send_status:
-            return
-        return msg.send_status.status
-
 admin.site.register(InboxMessage, InboxAdmin)
 admin.site.register(OutboxMessage, OutboxAdmin)
